@@ -19,7 +19,7 @@ sub mvp_multivalue_args { qw(
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2024-01-08'; # DATE
 our $DIST = 'Pod-Weaver-Plugin-Sah-Schemas'; # DIST
-our $VERSION = '0.075'; # VERSION
+our $VERSION = '0.076'; # VERSION
 
 sub weave_section {
     no strict 'refs'; ## no critic: TestingAndDebugging::ProhibitNoStrict
@@ -134,6 +134,7 @@ sub weave_section {
 
                 require Data::Clone;
                 require Data::Dump;
+                require Data::Sah::Util::Type;
 
                 my @pod;
                 my $sch = Data::Clone::clone($sch);
@@ -144,6 +145,14 @@ sub weave_section {
                 $dump =~ s/^/ /mg;
                 push @pod, $dump, "\n\n";
 
+                # link to base schema/type
+                my $type = Data::Sah::Util::Type::get_type($sch);
+                if (Data::Sah::Util::Type::is_type($type)) {
+                    push @pod, "Base type: L<$type|Data::Sah::Type::$type>\n\n";
+                } else {
+                    push @pod, "Base schema: L<$type|Sah::Schema::$type>\n\n";
+                }
+
                 # link to prefilters modules
                 my $prefilters = $sch->[1]{prefilters};
                 if ($prefilters && @$prefilters) {
@@ -437,7 +446,7 @@ Pod::Weaver::Plugin::Sah::Schemas - Plugin to use when building Sah::Schemas::*
 
 =head1 VERSION
 
-This document describes version 0.075 of Pod::Weaver::Plugin::Sah::Schemas (from Perl distribution Pod-Weaver-Plugin-Sah-Schemas), released on 2024-01-08.
+This document describes version 0.076 of Pod::Weaver::Plugin::Sah::Schemas (from Perl distribution Pod-Weaver-Plugin-Sah-Schemas), released on 2024-01-08.
 
 =head1 SYNOPSIS
 
